@@ -24,12 +24,10 @@ import sys
 import tempfile
 from datetime import datetime, timedelta
 from gettext import gettext as _
-from typing import List
+from typing import List, Optional
 
 import gi
 
-from ..util.busy import BusyAsyncCall
-
 gi.require_version("Gdk", "3.0")
 gi.require_version("Gtk", "3.0")
 
@@ -44,7 +42,7 @@ from lutris.game import GAME_START, GAME_STOPPED, Game, export_game, import_game
 from lutris.gui.dialogs import ErrorDialog, InstallOrPlayDialog, NoticeDialog, display_error
 from lutris.gui.dialogs.delegates import CommandLineUIDelegate, InstallUIDelegate, LaunchUIDelegate
 from lutris.gui.dialogs.issue import IssueReportWindow
-from lutris.gui.installerwindow import InstallationKind, InstallerWindow
+from lutris.gui.installerwindow import INSTALLATION_COMPLETED, INSTALLATION_FAILED, InstallationKind, InstallerWindow
 from lutris.gui.widgets.status_icon import LutrisStatusIcon
 from lutris.installer import get_installers
 from lutris.migrations import migrate
@@ -53,20 +51,22 @@ from lutris.runners import InvalidRunnerError, RunnerInstallationError, get_runn
 from lutris.services import get_enabled_services
 from lutris.startup import init_lutris, run_all_checks
 from lutris.style_manager import StyleManager
-from lutris.util import datapath, log, system
+from lutris.util import datapath, log, resources, system
 from lutris.util.http import HTTPError, Request
 from lutris.util.log import file_handler, logger
 from lutris.util.savesync import save_check, show_save_stats, upload_save
 from lutris.util.steam.appmanifest import AppManifest, get_appmanifests
 from lutris.util.steam.config import get_steamapps_dirs
 
+from ..util.busy import BusyAsyncCall
+from ..util.standalone_scripts import generate_script
 from .lutriswindow import LutrisWindow
 
 LUTRIS_EXPERIMENTAL_FEATURES_ENABLED = os.environ.get("LUTRIS_EXPERIMENTAL_FEATURES_ENABLED") == "1"
 
 
-class Application(Gtk.Application):
-    def __init__(self):
+class LutrisApplication(Gtk.Application):
+    def __init__(self) -> None:
         super().__init__(
             application_id="net.lutris.Lutris",
             flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE,
@@ -80,12 +80,14 @@ class Application(Gtk.Application):
         GAME_START.register(self.on_game_start)
         GAME_STOPPED.register(self.on_game_stopped)
         settings.SETTINGS_CHANGED.register(self.on_settings_changed)
+        INSTALLATION_COMPLETED.register(self.on_install_ended)
+        INSTALLATION_FAILED.register(self.on_install_ended)
 
         GLib.set_application_name(_("Lutris"))
         GLib.set_prgname("net.lutris.Lutris")
         self.force_updates = False
         self.css_provider = Gtk.CssProvider.new()
-        self.window = None
+        self.window: Optional[LutrisWindow] = None
         self.launch_ui_delegate = LaunchUIDelegate()
         self.install_ui_delegate = InstallUIDelegate()
 
@@ -94,7 +96,7 @@ class Application(Gtk.Application):
         self.tray = None
 
         self.quit_on_game_exit = False
-        self.style_manager = None
+        self.style_manager = StyleManager()
 
         if os.geteuid() == 0:
             NoticeDialog(_("Do not run Lutris as root."))
@@ -338,8 +340,6 @@ class Application(Gtk.Application):
         self.add_action(action)
         self.add_accelerator("<Primary>q", "app.quit")
 
-        self.style_manager = StyleManager()
-
     def do_activate(self):  # pylint: disable=arguments-differ
         if not self.window:
             self.window = LutrisWindow(application=self)
@@ -349,6 +349,8 @@ class Application(Gtk.Application):
     def start_runtime_updates(self) -> None:
         if os.environ.get("LUTRIS_SKIP_INIT"):
             logger.debug("Skipping initialization")
+        elif not self.window:
+            logger.error("Runtime updates can't be started with a LutrisWindow.")
         else:
             self.window.start_runtime_updates(self.force_updates)
 
@@ -358,7 +360,8 @@ class Application(Gtk.Application):
         if kwargs.get("runner"):
             return kwargs["runner"].name
         if kwargs.get("installers"):
-            return kwargs["installers"][0]["game_slug"]
+            installer = kwargs["installers"][0]
+            return installer.get("slug") or installer.get("game_slug")
         if kwargs.get("game"):
             return kwargs["game"].id
         return str(kwargs)
@@ -394,6 +397,7 @@ class Application(Gtk.Application):
             update_function(window_inst)
         self.app_windows[window_key] = window_inst
         window_inst.show()
+        window_inst.present()
         return window_inst
 
     def show_installer_window(self, installers, service=None, appid=None, installation_kind=InstallationKind.INSTALL):
@@ -427,19 +431,6 @@ class Application(Gtk.Application):
         # Workaround broken pygobject bindings
         command_line.do_print_literal(command_line, string + "\n")
 
-    def generate_script(self, db_game, script_path):
-        """Output a script to a file.
-        The script is capable of launching a game without the client
-        """
-
-        def on_error(error: BaseException) -> None:
-            logger.exception("Unable to generate script: %s", error)
-
-        game = Game(db_game["id"])
-        game.game_error.register(on_error)
-        game.reload_config()
-        game.write_script(script_path, self.launch_ui_delegate)
-
     def do_handle_local_options(self, options):
         # Text only commands
 
@@ -454,7 +445,6 @@ class Application(Gtk.Application):
     def do_command_line(self, command_line):  # noqa: C901  # pylint: disable=arguments-differ
         # pylint: disable=too-many-locals,too-many-return-statements,too-many-branches
         # pylint: disable=too-many-statements
-        # TODO: split into multiple methods to reduce complexity (35)
         options = command_line.get_options_dict()
 
         # Use stdout to output logs, only if no command line argument is
@@ -485,6 +475,23 @@ class Application(Gtk.Application):
         else:
             dest_dir = None
 
+        if options.contains("output-script"):
+            searchstring = options.lookup_value("output-script").get_string()
+            export_script_game = (
+                games_db.get_game_by_field(searchstring, "id")
+                or games_db.get_game_by_field(searchstring, "slug")
+                or games_db.get_game_by_field(searchstring, "installer_slug")
+            )
+
+            if not export_script_game or not export_script_game["id"]:
+                logger.warning(
+                    "No valid game (%s) provided to generate the script. Use the -l option to find suitable games!",
+                    searchstring,
+                )
+                return 1
+            generate_script(logger, self.launch_ui_delegate, export_script_game, f"{export_script_game['slug']}.sh")
+            return 0
+
         # List game
         if options.contains("list-games"):
             game_list = games_db.get_games(filters=({"installed": 1} if options.contains("installed") else None))
@@ -635,9 +642,6 @@ class Application(Gtk.Application):
 
         self.launch_ui_delegate = CommandLineUIDelegate(launch_config_name)
 
-        if options.contains("output-script"):
-            action = "write-script"
-
         revision = installer_info["revision"]
 
         installer_file = None
@@ -663,6 +667,11 @@ class Application(Gtk.Application):
                 installer_file = file_path
                 action = "install"
             else:
+                # Use the invoking process's cwd for relative paths, not the running instance's
+                if not os.path.isabs(installer_file):
+                    cwd = command_line.get_cwd()
+                    if cwd:
+                        installer_file = os.path.join(cwd, installer_file)
                 installer_file = os.path.abspath(installer_file)
                 action = "install"
 
@@ -698,13 +707,6 @@ class Application(Gtk.Application):
         if options.contains("reinstall"):
             action = "install"
 
-        if action == "write-script":
-            if not db_game or not db_game["id"]:
-                logger.warning("No game provided to generate the script")
-                return 1
-            self.generate_script(db_game, options.lookup_value("output-script").get_string())
-            return 0
-
         # Graphical commands
         self.set_tray_icon()
         self.activate()
@@ -760,6 +762,15 @@ class Application(Gtk.Application):
 
             if game.state == game.STATE_STOPPED and not self.window.is_visible():
                 self.quit()
+
+            if self.quit_on_game_exit:
+
+                def game_stop_signal_handler(signum, _frame):
+                    logger.debug("signal handler called with signal: %d", signum)
+                    game.stop()
+
+                signal.signal(signal.SIGTERM, game_stop_signal_handler)
+                signal.signal(signal.SIGINT, game_stop_signal_handler)
         elif self.window:
             # If we're showing the window, it will handle the delegated UI
             # from here on out, no matter what command line we got.
@@ -771,12 +782,13 @@ class Application(Gtk.Application):
             self.quit_on_game_exit = False
         return 0
 
-    def on_settings_changed(self, setting_key, new_value):
-        if setting_key == "preferred_theme":
-            self.style_manager.preferred_theme = new_value
-        elif setting_key == "show_tray_icon" and self.window:
-            if self.window.get_visible():
-                self.set_tray_icon()
+    def on_settings_changed(self, setting_key, new_value, section):
+        if section == "lutris":
+            if setting_key == "preferred_theme":
+                self.style_manager.preferred_theme = new_value
+            elif setting_key == "show_tray_icon" and self.window:
+                if self.window.get_visible():
+                    self.set_tray_icon()
         return True
 
     def on_game_start(self, game: Game) -> None:
@@ -805,6 +817,12 @@ class Application(Gtk.Application):
                 if self.quit_on_game_exit or not self.has_tray_icon():
                     self.quit()
 
+    def on_install_ended(self):
+        if not self.window or not self.window.is_visible():
+            if not self.has_running_games:
+                if self.quit_on_game_exit or not self.has_tray_icon():
+                    self.quit()
+
     def get_launch_ui_delegate(self):
         return self.launch_ui_delegate
 
@@ -867,8 +885,16 @@ class Application(Gtk.Application):
             )
 
     def print_game_json(self, command_line, game_list):
-        games = [
-            {
+        games = []
+
+        for game in game_list:
+            playtime = timedelta(hours=game["playtime"]) if game["playtime"] else None
+            cover_path = resources.get_cover_path(game["slug"]) if game["slug"] else None
+
+            if cover_path and not os.path.exists(cover_path):
+                cover_path = None
+
+            game_obj = {
                 "id": game["id"],
                 "slug": game["slug"],
                 "name": game["name"],
@@ -876,11 +902,14 @@ class Application(Gtk.Application):
                 "platform": game["platform"] or None,
                 "year": game["year"] or None,
                 "directory": game["directory"] or None,
-                "playtime": (str(timedelta(hours=game["playtime"])) if game["playtime"] else None),
+                "playtime": str(playtime) if playtime else None,
+                "playtimeSeconds": playtime.total_seconds() if playtime else None,
                 "lastplayed": (str(datetime.fromtimestamp(game["lastplayed"])) if game["lastplayed"] else None),
+                "coverPath": cover_path,
             }
-            for game in game_list
-        ]
+
+            games.append(game_obj)
+
         self._print(command_line, json.dumps(games, indent=2))
 
     def print_service_game_list(self, command_line, game_list):
