@@ -88,7 +88,7 @@ class GOGService(OnlineService):
 
     client_id = "46899977096215655"
     client_secret = "9d85c43b1482497dbbce61f6e4aa173a433796eeae2ca8c5f6129f2dc4de46d9"
-    redirect_uri = "https://embed.gog.com/on_login_success?origin=client"
+    redirect_uris = ["https://embed.gog.com/on_login_success?origin=client"]
 
     login_success_url = "https://www.gog.com/on_login_success"
     cookies_path = os.path.join(settings.CACHE_DIR, ".gog.auth")
@@ -116,7 +116,7 @@ class GOGService(OnlineService):
         params = {
             "client_id": self.client_id,
             "layout": "client2",
-            "redirect_uri": self.redirect_uri,
+            "redirect_uri": self.redirect_uris[0],
             "response_type": "code",
         }
         return "https://auth.gog.com/auth?" + urlencode(params)
@@ -170,7 +170,7 @@ class GOGService(OnlineService):
                 return
             extra_params = {
                 "code": response_params["code"],
-                "redirect_uri": self.redirect_uri,
+                "redirect_uri": self.redirect_uris[0],
             }
 
         params = {
@@ -180,7 +180,7 @@ class GOGService(OnlineService):
         }
         params.update(extra_params)
         url = "https://auth.gog.com/token?" + urlencode(params)
-        request = Request(url)
+        request = Request(url, redacted_query_parameters=("refresh_token", "code"))
         try:
             request.get()
         except HTTPError as http_error:
@@ -376,10 +376,11 @@ class GOGService(OnlineService):
         """Return available installers for a GOG game"""
         # Filter out Mac installers
         gog_installers = [installer for installer in downloads.get("installers", []) if installer["os"] != "mac"]
-        filter_os = self.runner_to_os_dict.get(runner)
-        # If it's a Linux game, also filter out Windows games
-        if filter_os:
-            gog_installers = [installer for installer in gog_installers if installer["os"] == filter_os]
+        # Prefer native Linux installers if available, otherwise fall back to Windows
+        # (scripts may need Windows installers for data extraction, engine reimplementations, etc.)
+        linux_installers = [installer for installer in gog_installers if installer["os"] == "linux"]
+        if linux_installers:
+            gog_installers = linux_installers
         return [
             installer
             for installer in gog_installers
