@@ -146,7 +146,7 @@ class GPU:
             if line.startswith("GPU"):
                 current_gpu = line
                 result[current_gpu] = {}
-            else:
+            elif "= " in line:
                 key, value = line.split("= ", maxsplit=1)
                 result[current_gpu][key.strip()] = value.strip()
         if "Failed to detect any valid GPUs" in result or "ERROR: [Loader Message]" in result:
@@ -156,20 +156,27 @@ class GPU:
 
     def get_vulkaninfo_name(self) -> Optional[str]:
         vulkaninfo = self.get_vulkaninfo()
+        best_name = None
         for gpu_index in vulkaninfo:
             pci_id = "%s:%s" % (
                 vulkaninfo[gpu_index]["vendorID"].replace("0x", ""),
                 vulkaninfo[gpu_index]["deviceID"].replace("0x", ""),
             )
             if pci_id == self.pci_id:
-                return vulkaninfo[gpu_index]["deviceName"]
-        return None
+                name = vulkaninfo[gpu_index]["deviceName"]
+                if not best_name or len(name) > len(best_name):
+                    best_name = name
+        return best_name
 
     def get_vulkaninfo_device_uuid(self) -> Optional[str]:
         vulkaninfo = self.get_vulkaninfo()
         for gpu_index in vulkaninfo:
-            device_uuid = vulkaninfo[gpu_index]["deviceUUID"].replace("-", "")
-            return device_uuid
+            pci_id = "%s:%s" % (
+                vulkaninfo[gpu_index]["vendorID"].replace("0x", ""),
+                vulkaninfo[gpu_index]["deviceID"].replace("0x", ""),
+            )
+            if pci_id == self.pci_id:
+                return vulkaninfo[gpu_index]["deviceUUID"].replace("-", "")
         return None
 
     def get_lspci_name(self):
