@@ -12,8 +12,8 @@ CHROME_USERAGENT = (
     "Chrome/72.0.3626.121 Safari/537.36"
 )
 
-CLUB_GENOME_ID = "85c31714-0941-4876-a18d-2c7e9dce8d40"
-CLUB_APPID = "314d4fef-e568-454a-ae06-43e3bece12a6"
+CLUB_GENOME_ID = "42d07c95-9914-4450-8b38-267c4e462b21"
+CLUB_APPID = "82b650c0-6cb3-40c0-9f41-25a53b62b206"
 
 LOGIN_URL = (
     f"https://connect.ubisoft.com/login?appId={CLUB_APPID}&genomeId={CLUB_GENOME_ID}"
